@@ -321,7 +321,7 @@ class TestBestMatch(TestCase):
 
     def test_one_error(self):
         validator = _LATEST_VERSION({"minProperties": 2})
-        error, = validator.iter_errors({})
+        validator.iter_errors({})
         self.assertEqual(
             exceptions.best_match(validator.iter_errors({})).validator,
             "minProperties",
